;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.6.0" "Cross-referencing commands" '((emacs "26.1")) :commit "65f35b7f6f4115291affa754855ad62a697524af" :url "https://elpa.gnu.org/packages/xref.html")
